Learn R Programming

MBCB (version 1.26.0)

bg.mcmc: MBCB - Bayesian Background Correction for Illumina Beadarray

Description

This function provides the means of using only the MCMC (Bayesian) background correction method for the Illumina platform.

Usage

bg.mcmc(iter=500, burn=200)

Arguments

iter
The iteration count for the Baysian correction.
burn
The number of iterations to burn for the Bayesian correction.

Value

This function returns an array of alpha, mu, and sigma values representing the values computed during the mcmc trial.

See Also

mbcb.main

Examples

Run this code
  data(MBCBExpressionData)
  # Use of global variables is obviously not ideal, but with R's pass-by-value 
  #   setup, we quickly run out of memory without using them on such large 
  #   arrays

  #all of the signals from sample #2
  obsbead <<- expressionSignal[,2]
  
  #the negative control values for this sample
  obsnc <<- negativeControl[,2]         
  
  #compute the alpha, mu, and sigma values
  bg.mcmc();                            

Run the code above in your browser using DataLab