Learn R Programming

MBCB (version 1.26.0)

bg.rma: MBCB - Robust Multi-Array Average Background Correction for Illumina Beadarray

Description

This function provides the means of using only the Robust Multi-Array Average background correction method for the Illumina platform.

Usage

bg.rma(pm, n.pts = 2^14)

Arguments

pm
The data to be background corrected.
n.pts
Pertains to the specificity or accuracy of the method. 2^14 is the default.

Value

A list with two values:
ex.rma:
A vector containing the background-corrected values.
para:
The statistical summary of the computation.

See Also

mbcb.main

Examples

Run this code
  data(MBCBExpressionData)
  
  bg.rma(expressionSignal[,2]); 

Run the code above in your browser using DataLab