data(MBCBExpressionData)
# Use of global variables is obviously not ideal, but with R's pass-by-value
# setup, we quickly run out of memory without using them on such large
# arrays
#all of the signals from sample #2
obsbead <<- expressionSignal[,2]
#the negative control values for this sample
obsnc <<- negativeControl[,2]
#compute the alpha, mu, and sigma values
bg.mcmc();
Run the code above in your browser using DataLab